searchData={"content_type":"text/markdown","items":[{"doc":"This module is as a simple wrapper around `OAuth2`, which helps building a valid configuration for authorizing with a [Keycloak](http://www.keycloak.org/) server.","ref":"Kloak.html","title":"Kloak","type":"module"},{"doc":"#### Phoenix controller\n    @doc \"Login controller action which redirects to Keycloak for authentication.\"\n    def login(conn, _) do\n      with {:ok, client} <- Kloak.Client.new(), {:ok, nonce} <- generate_nonce(),\n           {:ok, redirect_url} <- Kloak.authorization_url(client, scope: \"openid\", state: nonce, redirect_uri: url(~p\"/auth/callback\")) do\n        conn\n        |> put_oidc_state(nonce)\n        |> redirect(external: redirect_url)\n      end\n    end\n\n    @doc \"Callback controller action which is called when a users is redirected from Keycloak.\"\n    def callback(conn, %{\"code\" => code, \"state\" => state}) do\n      with {:ok, true} <- verify_oidc_state(conn, state),\n          {:ok, client} <- Kloak.Client.new(),\n          {:ok, token} <- Kloak.get_token(client, code: code, redirect_uri: url(~p\"/auth/callback\")),\n          {:ok, client} <- Kloak.Client.new(token: token),\n          {:ok, user_information} <- Kloak.user_information(client) do\n        # Do something with the user information\n        IO.inspect(user_information)\n\n        # Authentication was successful\n        conn\n        |> put_session(:token, token)\n        |> put_flash(:info, gettext(\"You have successfully logged in.\"))\n        |> redirect(to: ~p\"/dashboard\")\n      end\n    end","ref":"Kloak.html#module-examples","title":"Examples - Kloak","type":"module"},{"doc":"Build the autorization URL, which is required in the authentication flow.\nThis built URL is used for redirecting to Keycloak.","ref":"Kloak.html#authorize_url/2","title":"Kloak.authorize_url/2","type":"function"},{"doc":"iex> authorize_url(%OAuth2.Client{...})\n    {:ok, \"https://localhost:4000/...\"}\n\n    iex> authorize_url(%OAuth2.Client{...})\n    {:error, \"Building the authorization URL failed with an invalid URL\"}\n\n    iex> authorize_url(%OAuth2.Client{...})\n    {:error, \"Building the authorization URL failed with an unknown error\"}","ref":"Kloak.html#authorize_url/2-examples","title":"Examples - Kloak.authorize_url/2","type":"function"},{"doc":"Try to get the access token from Keycloak with the given, preconfigured `OAuth2.Client`.","ref":"Kloak.html#get_token/4","title":"Kloak.get_token/4","type":"function"},{"doc":"iex> get_token(%OAuth2.Client{...})\n    {:ok, %OAuth2.AccessToken{...}}\n\n    iex> get_token(%OAuth2.Client{...})\n    {:error, \"Getting the access token from Keycloak failed\"}","ref":"Kloak.html#get_token/4-examples","title":"Examples - Kloak.get_token/4","type":"function"},{"doc":"Fetches the user information of the authenticated user from the Keycloak userinfo endpoint.\nThe passed `OAuth2.Client` must be properly configured and authorized to perform this action.","ref":"Kloak.html#user_information/1","title":"Kloak.user_information/1","type":"function"},{"doc":"iex> user_information(valid_client)\n    {:ok, %{\"given_name\" => \"John\", ...}}\n\n    iex> user_information(invalid_client)\n    {:error, \"Retriving user information from Keycloak failed with an error\"}\n\n    iex> user_information(invalid_client)\n    {:error, \"Retriving user information failed due to an invalid realm configuration\"}","ref":"Kloak.html#user_information/1-examples","title":"Examples - Kloak.user_information/1","type":"function"},{"doc":"Wrapper for building a properly configured `OAuth2.Client` which can be used with Keycloak.","ref":"Kloak.Client.html","title":"Kloak.Client","type":"module"},{"doc":"```elxir\n  config :kloak,\n    site:  \n    realm:  \n    client_id:  \n    client_secret:  \n  ```","ref":"Kloak.Client.html#module-configuration","title":"Configuration - Kloak.Client","type":"module"},{"doc":"Build a properly preconfigured `OAuth2.Client` for communicating with Keycloak.","ref":"Kloak.Client.html#new/1","title":"Kloak.Client.new/1","type":"function"},{"doc":"iex> new()\n    {:ok, %OAuth2.Client{}}\n\n    iex> new()\n    {:error, \"Building the client failed due to an invalid configuration\"}\n\n    iex> new()\n    {:error, \"Building the client failed due to an error loading the configuration\"}\n\n    iex> new(nil)\n    {:error, \"Building the client failed due to invalid options\"}","ref":"Kloak.Client.html#new/1-examples","title":"Examples - Kloak.Client.new/1","type":"function"},{"doc":"Fetches the user information of the authenticated user from the Keycloak userinfo endpoint.\nThe passed `OAuth2.Client` must be properly configured and authorized to perform this action.","ref":"Kloak.Client.html#user_information/1","title":"Kloak.Client.user_information/1","type":"function"},{"doc":"iex> user_information(valid_client)\n    {:ok, %{\"given_name\" => \"John\", ...}}\n\n    iex> user_information(invalid_client)\n    {:error, \"Fetching user information from Keycloak failed with an error\"}\n\n    iex> user_information(invalid_client)\n    {:error, \"Fetching user information failed due to an error loading the configuration\"}\n\n    iex> user_information(nil)\n    {:error, \"Fetching user information failed due to an invalid OAuth client\"}","ref":"Kloak.Client.html#user_information/1-examples","title":"Examples - Kloak.Client.user_information/1","type":"function"},{"doc":"Utility module which offers some functionality for other modules.","ref":"Kloak.Utils.html","title":"Kloak.Utils","type":"module"},{"doc":"Fetches and retruns a setting fetched under the given key or path.\nWhen the setting was not found under the given key/path, the given default value is returned.\nAccording to `Application.compile_env/3` and `Application.compile_env!/2` it's possible to provide a key or a path of keys to fetch a setting.","ref":"Kloak.Utils.html#fetch_env/3","title":"Kloak.Utils.fetch_env/3","type":"function"},{"doc":"iex> fetch_env(:keymaster, [:key_1, :key_2, :key_3])\n    \"value3\"\n\n    iex> fetch_env(:keymaster, [:key_1, :key_2, :key_3], \"default\")\n    \"default\"\n\n    iex> fetch_env(:keymaster, :other_key)\n    \"other_value\"","ref":"Kloak.Utils.html#fetch_env/3-examples","title":"Examples - Kloak.Utils.fetch_env/3","type":"function"},{"doc":"Fetches and retruns a setting fetched under the given key or path.\nWhen the setting was not found under the given key/path, an ArgumentError will be raised.\nAccording to `Application.compile_env/3` and `Application.compile_env!/2` it's possible to provide a key or a path of keys to fetch a setting.","ref":"Kloak.Utils.html#fetch_env!/2","title":"Kloak.Utils.fetch_env!/2","type":"function"},{"doc":"iex> fetch_env!(:keymaster, [:key_1, :key_2, :key_3])\n    \"value3\"\n\n    iex> fetch_env!(:keymaster, [:key_1, :key_2, :key_3])\n    ArgumentError\n\n    iex> fetch_env(:keymaster, :other_key)\n    \"other_value\"","ref":"Kloak.Utils.html#fetch_env!/2-examples","title":"Examples - Kloak.Utils.fetch_env!/2","type":"function"},{"doc":"# Kloak\nKloak is a simple wrapper for [OAuth2](https://hex.pm/packages/oauth2), which can be used for authenticating users with [Phoenix](https://hex.pm/packages/phoenix) and a [Keycloak](https://www.keycloak.org/) IDM.","ref":"readme.html","title":"Kloak","type":"extras"},{"doc":"The package can be installed by adding `kloak` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:kloak, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - Kloak","type":"extras"},{"doc":"Using `Kloak` with a `Phoenix` application is quite easy. To perform authentication with Keycloak, you need to implement at least one `login` and one `callback` controller function e.g. in your `authentication_controller`.\n\n```elixir\n@doc \"Login controller action which redirects to Keycloak for authentication.\"\ndef login(conn, _) do\n  with {:ok, client} <- Kloak.Client.new(),\n       {:ok, nonce} <- generate_nonce(),\n       {:ok, redirect_url} <- Kloak.authorization_url(client, scope: \"openid\", state: nonce, redirect_uri: url(~p\"/auth/callback\")) do\n    conn\n    |> put_oidc_state(nonce)\n    |> redirect(external: redirect_url)\n  end\nend\n```\n\n```elixir\n@doc \"Callback controller action which is called when a users is redirected from Keycloak.\"\ndef callback(conn, %{\"code\" => code, \"state\" => state}) do\n  with {:ok, true} <- verify_oidc_state(conn, state),\n       {:ok, client} <- Kloak.Client.new(),\n       {:ok, token} <- Kloak.get_token(client, code: code, redirect_uri: url(~p\"/auth/callback\")),\n       {:ok, client} <- Kloak.Client.new(token: token),\n       {:ok, user_information} <- Kloak.user_information(client) do\n    # Do something with the user information\n    IO.inspect(user_information)\n\n    # Authentication was successful\n    conn\n    |> put_session(:token, token)\n    |> put_flash(:info, gettext(\"You have successfully logged in.\"))\n    |> redirect(to: ~p\"/dashboard\")\n  end\nend\n```","ref":"readme.html#usage","title":"Usage - Kloak","type":"extras"},{"doc":"The MIT License (MIT). Please see [LICENSE](LICENSE) for more information.","ref":"readme.html#license","title":"License - Kloak","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}